@@ -1,24 +1,22 @@
 from typing import Generic, TYPE_CHECKING, TypeVar
-from uuid import UUID
-
-from pymongo import ReturnDocument
 
 from deci_common.abstractions.base_model import DBSchema
-from deci_common.data_connection.mongo_db_connector import MongoDBConfiguration, MongoDBConnector
 from deci_common.abstractions.abstract_logger import ILogger
 
 if TYPE_CHECKING:
     from typing import Any, Dict, List, Type
+    from uuid import UUID
 
+    from deci_common.data_interfaces.mongo_db_interface import MongoDBInterface
 
 T = TypeVar("T", bound=DBSchema)
 
 
 class DBInterface(Generic[T], ILogger):
-    def __init__(self, element_type: "Type[T]", mongo_db_configuration: "Type[MongoDBConfiguration]"):
+    def __init__(self, element_type: "Type[T]", mongo_db_interface: "MongoDBInterface[Dict[str, Any]]"):
         super().__init__()
         self._element_type = element_type
-        self._db_connector = MongoDBConnector(mongo_db_configuration)
+        self._mongo_db_interface = mongo_db_interface
 
     def insert(self, element: "T") -> "T":
         """
@@ -26,8 +24,7 @@ class DBInterface(Generic[T], ILogger):
         @param element: The element to insert
         @return: T
         """
-        with self._db_connector as db:
-            db._insert_document(element.dict())
+        self._mongo_db_interface.insert(element.dict())
         return element
 
     def find(self, search_filter: "Dict[str, Any]" = {}) -> "List[T]":
@@ -36,8 +33,7 @@ class DBInterface(Generic[T], ILogger):
         @param search_filter: Filter for the search
         @return: List[T]
         """
-        with self._db_connector as db:
-            elements = db._get_documents(search_filter=search_filter)
+        elements = self._mongo_db_interface.find(search_filter=search_filter)
 
         return [self._element_type(**element) for element in elements]
 
@@ -47,11 +43,8 @@ class DBInterface(Generic[T], ILogger):
         @param element: The element to update to (id is used to find the element to update)
         @return: T
         """
-        with self._db_connector as db:
-            updated_element = db._update_and_return_document(
-                search_filter={"id": element.id}, updated_document=element.dict(), return_document=ReturnDocument.AFTER
-            )
-        return self._element_type(**updated_element)
+        self._mongo_db_interface.update(search_filter={"id": element.id}, updated_document=element.dict())
+        return element
 
     def update_many(self, updated_document: "Dict[str, Any]", search_filter: "Dict[str, Any]" = {}) -> "List[T]":
         """
@@ -60,28 +53,22 @@ class DBInterface(Generic[T], ILogger):
         :param search_filter: documents to update values for
         :return: List[T]
         """
-        with self._db_connector as db:
-            elements = db._update_many_and_return_documents(
-                search_filter=search_filter, updated_document=updated_document
-            )
-        return [self._element_type(**element) for element in elements]
+        self._mongo_db_interface.update(search_filter=search_filter, updated_document=updated_document)
+        return self.find(search_filter=search_filter)
 
-    def delete(self, id: "UUID", force=False) -> bool:
+    def delete(self, _id: "UUID", force: bool = False) -> bool:
         """
         Deletes an element from the DB
-        @param id: The ID of the element to delete
+        @param _id: The ID of the element to delete
         @param force: if True, permanently delete the element from the DB, otherwise - just mark it as deleted
         @return: True on success, False otherwise
         """
-        with self._db_connector as db:
-            if force:
-                delete_result = db._delete_document(search_filter={"id": id})
-                return delete_result.deleted_count == 1
-            updated_element = db._update_and_return_document(
-                search_filter={"id": id}, updated_document={"deleted": True}, return_document=ReturnDocument.AFTER
-            )
-            return updated_element["deleted"]
+        search_filter = {"id": _id}
+        if force:
+            delete_result = self._mongo_db_interface.delete(search_filter=search_filter)
+            return delete_result.deleted_count == 1
+        update_result = self._mongo_db_interface.update(search_filter=search_filter, updated_document={"deleted": True})
+        return update_result.modified_count == 1
 
     def increment_fields(self, *, search_filter: "Dict[str, Any]", fields: "Dict[str, int]") -> bool:
-        with self._db_connector as db:
-            return db.increment_a_field(search_filter=search_filter, increment_query=fields)
+        return self._mongo_db_interface.increment_field(search_filter=search_filter, increment_query=fields)
